/*
Serial RB control - Copyright (C) KI6ZUM 2015
Copyright (C) 2015 by Jonathan Naylor G4KLX

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the
Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
Boston, MA  02110-1301, USA.
*/

#include "SerialRB.h"

CSerialRB::CSerialRB() :
m_buffer(),
m_head(0U),
m_tail(0U)
{
}

void CSerialRB::reset()
{
  m_head = 0U;
  m_tail = 0U;
}

uint16_t CSerialRB::getSpace() const
{
  if (m_tail == m_head)
    return SERIAL_RINGBUFFER_SIZE;
  else if (m_tail < m_head)
    return SERIAL_RINGBUFFER_SIZE - m_head + m_tail;
  else
    return m_tail - m_head;
}

uint16_t CSerialRB::getData() const
{
  if (m_tail == m_head)
    return 0U;
  else if (m_tail < m_head)
    return m_head - m_tail;
  else
    return SERIAL_RINGBUFFER_SIZE - m_tail + m_head;
}

void CSerialRB::put(uint8_t c)
{
  m_buffer[m_head] = c;

  m_head = (m_head + 1U) % SERIAL_RINGBUFFER_SIZE;
}

uint8_t CSerialRB::peek() const
{
  return m_buffer[m_tail];
}

uint8_t CSerialRB::get()
{
  uint8_t value = m_buffer[m_tail];

  m_tail = (m_tail + 1U) % SERIAL_RINGBUFFER_SIZE;

  return value;
}

